from skeleton.settings_qa_base import *


FOUNDRY['layers'] = ('smart', 'basic',)
SITE_ID = 4
